{% extends "account/base.html" %}

{% block head_title %}Sign out{% endblock %}

{% block whitebox %}
<form method="post" action="{% url 'account_logout' %}">
  {% csrf_token %}
  <p>Are you sure you want to sign out?</p>
  {% include "account/_button.html" with text="Sign out" %}
</form>
{% endblock %}
